@@ -1,7 +1,7 @@
 use std::cell::RefCell;
 use std::net::{SocketAddr, ToSocketAddrs};
 use std::time::Duration;
-use crate::codec::{BinCodec, Codec, Codecs};
+use crate::codec::Codec;
 use crate::stub::ClientStub;
 use dark_std::errors::Result;
 use serde::de::DeserializeOwned;
@@ -12,20 +12,20 @@ use tokio::net::TcpStream;
 use tokio::sync::Mutex;
 
 #[derive(Debug)]
-pub struct Client {
+pub struct Client<C: Codec> {
     pub addr: String,
-    pub codec: Codecs,
+    pub codec: C,
     pub stub: ClientStub,
     pub stream: Mutex<TcpStream>,
 }
 
-impl Client {
+impl<C: Codec> Client<C> {
     pub async fn dial(addr: &str) -> std::io::Result<Self> {
         let address = addr.to_string();
         let stream = TcpStream::connect(addr).await?;
         Ok(Self {
             addr: address,
-            codec: Codecs::BinCodec(BinCodec {}),
+            codec: C::default(),
             stub: ClientStub::new(),
             stream: Mutex::new(stream),
         })
@@ -49,7 +49,7 @@ impl Client {
     }
 }
 
-impl RpcClient for Client {
+impl<C: Codec> RpcClient for Client<C> {
     fn addr(&self) -> &str {
         self.addr.as_str()
     }
